Class: ImageOptim::Config
- Inherits:
-
Object
- Object
- ImageOptim::Config
- Includes:
- OptionHelpers
- Defined in:
- lib/image_optim/config.rb
Overview
Read, merge and parse configuration
Constant Summary collapse
- GLOBAL_PATH =
Global config path at ‘$XDG_CONFIG_HOME/image_optim.yml` (by default `~/.config/image_optim.yml`)
File.join(ENV.fetch('XDG_CONFIG_HOME', '~/.config'), 'image_optim.yml')
- LOCAL_PATH =
Local config path at ‘./.image_optim.yml`
'./.image_optim.yml'
Class Method Summary collapse
- .load_yaml_file(path) ⇒ Object
-
.read_options(path) ⇒ Object
Read options at path: expand path (warn on failure), return {} if file does not exist or is empty, read yaml, check if it is a Hash, deep symbolise keys.
Instance Method Summary collapse
-
#allow_lossy ⇒ Object
Allow lossy workers and optimizations, converted to boolean.
-
#assert_no_unused_options! ⇒ Object
Fail unless all options were marked as used (directly or indirectly accessed using ‘get!`).
- #cache_dir ⇒ Object
-
#cache_worker_digests ⇒ Object
rubocop:disable Naming/PredicateMethod.
-
#for_worker(klass) ⇒ Object
Options for worker class by its ‘bin_sym`: * `Hash` passed as is * `{}` for `true` or `nil` * `false` for `false` * otherwise fail with `ConfigurationError`.
-
#get!(key) ⇒ Object
Gets value for key converted to symbol and mark option as used.
-
#initialize(options) ⇒ Config
constructor
Merge config from files with passed options Config files are checked at ‘GLOBAL_PATH` and `LOCAL_PATH` unless overriden using `:config_paths`.
-
#key?(key) ⇒ Boolean
Check if key is present.
-
#nice ⇒ Object
Nice level: * ‘10` by default and for `nil` or `true` * `0` for `false` * otherwise convert to integer.
-
#pack ⇒ Object
Using image_optim_pack: * ‘false` to disable * `nil` to use if available * everything else to require.
-
#skip_missing_workers ⇒ Object
Skip missing workers, converted to boolean.
-
#threads ⇒ Object
Number of parallel threads: * ‘processor_count` by default and for `nil` or `true` * `1` for `false` * otherwise convert to integer.
-
#timeout ⇒ Object
Timeout in seconds for each image: * not set by default and for ‘nil` * otherwise converted to float.
-
#to_s ⇒ Object
yaml dump without document beginning prefix ‘—`.
-
#verbose ⇒ Object
Verbose mode, converted to boolean.
Methods included from OptionHelpers
Constructor Details
#initialize(options) ⇒ Config
Merge config from files with passed options Config files are checked at ‘GLOBAL_PATH` and `LOCAL_PATH` unless overriden using `:config_paths`
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/image_optim/config.rb', line 60 def initialize() config_paths = .delete(:config_paths) || [GLOBAL_PATH, LOCAL_PATH] config_paths = Array(config_paths) to_merge = config_paths.map{ |path| self.class.(path) } to_merge << HashHelpers.deep_symbolise_keys() @options = to_merge.reduce do |memo, hash| HashHelpers.deep_merge(memo, hash) end @used = Set.new end |
Class Method Details
.load_yaml_file(path) ⇒ Object
48 49 50 51 52 53 54 |
# File 'lib/image_optim/config.rb', line 48 def load_yaml_file(path) if YAML.respond_to?(:safe_load_file) YAML.safe_load_file(path, permitted_classes: [Range]) else YAML.load_file(path) end end |
.read_options(path) ⇒ Object
Read options at path: expand path (warn on failure), return {} if file does not exist or is empty, read yaml, check if it is a Hash, deep symbolise keys
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/image_optim/config.rb', line 28 def (path) begin full_path = File.(path) rescue ArgumentError => e warn "Can't expand path #{path}: #{e}" return {} end return {} unless File.size?(full_path) config = load_yaml_file(full_path) unless config.is_a?(Hash) fail "expected hash, got #{config.inspect}" end HashHelpers.deep_symbolise_keys(config) rescue => e warn "exception when reading #{full_path}: #{e}" {} end |
Instance Method Details
#allow_lossy ⇒ Object
Allow lossy workers and optimizations, converted to boolean
168 169 170 |
# File 'lib/image_optim/config.rb', line 168 def allow_lossy # rubocop:disable Naming/PredicateMethod !!get!(:allow_lossy) end |
#assert_no_unused_options! ⇒ Object
Fail unless all options were marked as used (directly or indirectly accessed using ‘get!`)
88 89 90 91 92 93 |
# File 'lib/image_optim/config.rb', line 88 def = @options.reject{ |key, _value| @used.include?(key) } return if .empty? fail ConfigurationError, "unknown options #{.inspect}" end |
#cache_dir ⇒ Object
172 173 174 175 |
# File 'lib/image_optim/config.rb', line 172 def cache_dir dir = get!(:cache_dir) dir unless dir.nil? || dir.empty? end |
#cache_worker_digests ⇒ Object
rubocop:disable Naming/PredicateMethod
177 178 179 |
# File 'lib/image_optim/config.rb', line 177 def cache_worker_digests # rubocop:disable Naming/PredicateMethod !!get!(:cache_worker_digests) end |
#for_worker(klass) ⇒ Object
Options for worker class by its ‘bin_sym`:
-
‘Hash` passed as is
-
‘{}` for `true` or `nil`
-
‘false` for `false`
-
otherwise fail with ‘ConfigurationError`
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/image_optim/config.rb', line 186 def for_worker(klass) = get!(klass.bin_sym) case when Hash when true, nil {} when false {disable: true} else fail ConfigurationError, "Got #{.inspect} for " \ "#{klass.name} options" end end |
#get!(key) ⇒ Object
Gets value for key converted to symbol and mark option as used
74 75 76 77 78 |
# File 'lib/image_optim/config.rb', line 74 def get!(key) key = key.to_sym @used << key @options[key] end |
#key?(key) ⇒ Boolean
Check if key is present
81 82 83 84 |
# File 'lib/image_optim/config.rb', line 81 def key?(key) key = key.to_sym @options.key?(key) end |
#nice ⇒ Object
Nice level:
-
‘10` by default and for `nil` or `true`
-
‘0` for `false`
-
otherwise convert to integer
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/image_optim/config.rb', line 99 def nice nice = get!(:nice) case nice when true, nil 10 when false 0 else nice.to_i end end |
#pack ⇒ Object
Using image_optim_pack:
-
‘false` to disable
-
‘nil` to use if available
-
everything else to require
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/image_optim/config.rb', line 146 def pack pack = get!(:pack) return false if pack == false require 'image_optim/pack' true rescue LoadError => e raise "Cannot load image_optim_pack: #{e}" if pack false end |
#skip_missing_workers ⇒ Object
Skip missing workers, converted to boolean
159 160 161 162 163 164 165 |
# File 'lib/image_optim/config.rb', line 159 def skip_missing_workers if key?(:skip_missing_workers) !!get!(:skip_missing_workers) else pack end end |
#threads ⇒ Object
Number of parallel threads:
-
‘processor_count` by default and for `nil` or `true`
-
‘1` for `false`
-
otherwise convert to integer
116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/image_optim/config.rb', line 116 def threads threads = get!(:threads) case threads when true, nil processor_count when false 1 else threads.to_i end end |
#timeout ⇒ Object
Timeout in seconds for each image:
-
not set by default and for ‘nil`
-
otherwise converted to float
132 133 134 135 |
# File 'lib/image_optim/config.rb', line 132 def timeout timeout = get!(:timeout) timeout ? timeout.to_f : nil end |
#to_s ⇒ Object
yaml dump without document beginning prefix ‘—`
203 204 205 |
# File 'lib/image_optim/config.rb', line 203 def to_s YAML.dump(HashHelpers.deep_stringify_keys(@options)).sub(/\A---\n/, '') end |
#verbose ⇒ Object
Verbose mode, converted to boolean
138 139 140 |
# File 'lib/image_optim/config.rb', line 138 def verbose # rubocop:disable Naming/PredicateMethod !!get!(:verbose) end |