Class: ImageOptim

Inherits:
Object
  • Object
show all
Defined in:
lib/image_optim.rb,
lib/image_optim/cmd.rb,
lib/image_optim/path.rb,
lib/image_optim/cache.rb,
lib/image_optim/space.rb,
lib/image_optim/config.rb,
lib/image_optim/runner.rb,
lib/image_optim/worker.rb,
lib/image_optim/handler.rb,
lib/image_optim/cache_path.rb,
lib/image_optim/image_meta.rb,
lib/image_optim/worker/svgo.rb,
lib/image_optim/bin_resolver.rb,
lib/image_optim/hash_helpers.rb,
lib/image_optim/worker/jhead.rb,
lib/image_optim/worker/advpng.rb,
lib/image_optim/worker/pngout.rb,
lib/image_optim/optimized_path.rb,
lib/image_optim/option_helpers.rb,
lib/image_optim/true_false_nil.rb,
lib/image_optim/worker/optipng.rb,
lib/image_optim/worker/gifsicle.rb,
lib/image_optim/worker/jpegtran.rb,
lib/image_optim/worker/pngcrush.rb,
lib/image_optim/worker/pngquant.rb,
lib/image_optim/bin_resolver/bin.rb,
lib/image_optim/worker/jpegoptim.rb,
lib/image_optim/option_definition.rb,
lib/image_optim/bin_resolver/error.rb,
lib/image_optim/configuration_error.rb,
lib/image_optim/runner/glob_helpers.rb,
lib/image_optim/runner/option_parser.rb,
lib/image_optim/worker/class_methods.rb,
lib/image_optim/worker/jpegrecompress.rb,
lib/image_optim/non_negative_integer_range.rb,
lib/image_optim/bin_resolver/simple_version.rb,
lib/image_optim/bin_resolver/comparable_condition.rb

Overview

Main interface

Defined Under Namespace

Modules: Cmd, HashHelpers, ImageMeta, OptionHelpers, Space Classes: BinResolver, Cache, CachePath, Config, ConfigurationError, Handler, NonNegativeIntegerRange, OptimizedPath, OptionDefinition, Path, Runner, TrueFalseNil, Worker

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ ImageOptim

Initialize workers, specify options using worker underscored name:

pass false to disable worker

ImageOptim.new(:pngcrush => false)

or hash with options to worker

ImageOptim.new(:advpng => {:level => 3}, :optipng => {:level => 2})

use :threads to set number of parallel optimizers to run (passing true or nil determines number of processors, false disables parallel processing)

ImageOptim.new(:threads => 8)

use :nice to specify optimizers nice level (true or nil makes it 10, false makes it 0)

ImageOptim.new(:nice => 20)


66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/image_optim.rb', line 66

def initialize(options = {})
  config = Config.new(options)
  @verbose = config.verbose
  $stderr << "config:\n#{config.to_s.gsub(/^/, '  ')}" if verbose

  %w[
    nice
    threads
    pack
    skip_missing_workers
    allow_lossy
    cache_dir
    cache_worker_digests
  ].each do |name|
    instance_variable_set(:"@#{name}", config.send(name))
    $stderr << "#{name}: #{send(name)}\n" if verbose
  end

  @bin_resolver = BinResolver.new(self)

  $stderr << "PATH: #{@bin_resolver.env_path}\n" if verbose

  @workers_by_format = Worker.create_all_by_format(self) do |klass|
    config.for_worker(klass)
  end

  @cache = Cache.new(self, @workers_by_format)

  log_workers_by_format if verbose

  config.assert_no_unused_options!
end

Instance Attribute Details

#allow_lossyObject (readonly)

Allow lossy workers and optimizations



39
40
41
# File 'lib/image_optim.rb', line 39

def allow_lossy
  @allow_lossy
end

#cache_dirObject (readonly)

Cache directory



42
43
44
# File 'lib/image_optim.rb', line 42

def cache_dir
  @cache_dir
end

#cache_worker_digestsObject (readonly)

Cache worker digests



45
46
47
# File 'lib/image_optim.rb', line 45

def cache_worker_digests
  @cache_worker_digests
end

#niceObject (readonly)

Nice level



24
25
26
# File 'lib/image_optim.rb', line 24

def nice
  @nice
end

#packObject (readonly)

Use image_optim_pack



33
34
35
# File 'lib/image_optim.rb', line 33

def pack
  @pack
end

#skip_missing_workersObject (readonly)

Skip workers with missing or problematic binaries



36
37
38
# File 'lib/image_optim.rb', line 36

def skip_missing_workers
  @skip_missing_workers
end

#threadsObject (readonly)

Number of threads to run with



27
28
29
# File 'lib/image_optim.rb', line 27

def threads
  @threads
end

#verboseObject (readonly)

Verbose output?



30
31
32
# File 'lib/image_optim.rb', line 30

def verbose
  @verbose
end

Class Method Details

.full_versionObject

Full version of image_optim



200
201
202
# File 'lib/image_optim.rb', line 200

def full_version
  "image_optim v#{version}"
end

.method_missing(method, *args, &block) ⇒ Object

Optimization methods with default options



174
175
176
177
178
179
180
# File 'lib/image_optim.rb', line 174

def method_missing(method, *args, &block)
  if optimize_image_method?(method)
    new.send(method, *args, &block)
  else
    super
  end
end

.respond_to_missing?(method, include_private = false) ⇒ Boolean

Returns:

  • (Boolean)


182
183
184
# File 'lib/image_optim.rb', line 182

def respond_to_missing?(method, include_private = false)
  optimize_image_method?(method) || super
end

.versionObject

Version of image_optim gem spec loaded



193
194
195
196
197
# File 'lib/image_optim.rb', line 193

def version
  Gem.loaded_specs['image_optim'].version.to_s
rescue
  'DEV'
end

Instance Method Details

#env_pathObject

Join resolve_dir, default path and vendor path for PATH environment variable



223
224
225
# File 'lib/image_optim.rb', line 223

def env_path
  @bin_resolver.env_path
end

#optimizable?(path) ⇒ Boolean

Are there workers for file at path?

Returns:

  • (Boolean)


212
213
214
# File 'lib/image_optim.rb', line 212

def optimizable?(path)
  !!workers_for_image(path)
end

#optimize_image(original) ⇒ Object

Optimize one file, return new path as OptimizedPath or nil if optimization failed



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/image_optim.rb', line 106

def optimize_image(original)
  original = Path.convert(original)
  return unless (workers = workers_for_image(original))

  optimized = @cache.fetch(original) do
    Handler.for(original) do |handler|
      workers.each do |worker|
        handler.process do |src, dst|
          worker.optimize(src, dst)
        end
      end
    end
  end

  return unless optimized
  OptimizedPath.new(optimized, original)
end

#optimize_image!(original) ⇒ Object

Optimize one file in place, return original as OptimizedPath or nil if optimization failed



126
127
128
129
130
131
# File 'lib/image_optim.rb', line 126

def optimize_image!(original)
  original = Path.convert(original)
  return unless (result = optimize_image(original))
  result.replace(original)
  OptimizedPath.new(original, result.original_size)
end

#optimize_image_data(original_data) ⇒ Object

Optimize image data, return new data or nil if optimization failed



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/image_optim.rb', line 134

def optimize_image_data(original_data)
  format = ImageMeta.format_for_data(original_data)
  return unless format
  Path.temp_file %W[image_optim .#{format}] do |temp|
    temp.binmode
    temp.write(original_data)
    temp.close

    if (result = optimize_image(temp.path))
      result.binread
    end
  end
end

#optimize_images(paths, &block) ⇒ Object

Optimize multiple images if block given yields path and result for each image and returns array of yield results else return array of path and result pairs



152
153
154
# File 'lib/image_optim.rb', line 152

def optimize_images(paths, &block)
  run_method_for(paths, :optimize_image, &block)
end

#optimize_images!(paths, &block) ⇒ Object

Optimize multiple images in place if block given yields path and result for each image and returns array of yield results else return array of path and result pairs



160
161
162
# File 'lib/image_optim.rb', line 160

def optimize_images!(paths, &block)
  run_method_for(paths, :optimize_image!, &block)
end

#optimize_images_data(datas, &block) ⇒ Object

Optimize multiple image datas if block given yields original and result for each image data and returns array of yield results else return array of path and result pairs



168
169
170
# File 'lib/image_optim.rb', line 168

def optimize_images_data(datas, &block)
  run_method_for(datas, :optimize_image_data, &block)
end

#resolve_bin!(bin) ⇒ Object

Check existance of binary, create symlink if ENV contains path for key XXX_BIN where XXX is upper case bin name



218
219
220
# File 'lib/image_optim.rb', line 218

def resolve_bin!(bin)
  @bin_resolver.resolve!(bin)
end

#respond_to?(method, include_private = false) ⇒ Boolean

Returns:

  • (Boolean)


187
188
189
# File 'lib/image_optim.rb', line 187

def respond_to?(method, include_private = false)
  optimize_image_method?(method) || super
end

#workers_for_image(path) ⇒ Object

Get workers for image



100
101
102
# File 'lib/image_optim.rb', line 100

def workers_for_image(path)
  @workers_by_format[Path.convert(path).image_format]
end